@@ -1,13 +1,13 @@
 var indexSectionsWithContent =
 {
-  0: "abcdefgilnopstuw",
+  0: "123456789abcdefghiklmnoprstuwxy",
   1: "bcdefgps",
   2: "acdgilosuw",
   3: "acdefgilnsu",
   4: "s",
   5: "s",
-  6: "et",
-  7: "bcdt"
+  6: "abcefhiklmpstw",
+  7: "123456789abcdfhiloprstuw"
 };
 
 var indexSectionNames =
